.. _api-ref:

###############
API Reference
###############

For detailed information on the chemistry-related objects and reaction definitions used in
MusicBox via MUSICA, see :mod:`musica.mechanism_configuration`.

.. toctree::
   :maxdepth: 4
   :caption: Python

   acom_music_box

.. toctree::
   :maxdepth: 4
   :caption: JavaScript

   javascript
